@@ -147,7 +147,8 @@ def _listVersions(namespace, name):
     
     if response.status_code == 404:
         raise access_common.ComponentUnavailable(
-            '%s does not exist in the %s registry' % (name, namespace)
+            ('%s does not exist in the %s registry. '+
+            'Check that the name is correct, and that it has been published.') % (name, namespace)
         )
 
     # raise any other HTTP errors
@@ -306,7 +307,7 @@ def listOwners(namespace, name):
     response = requests.get(url, headers=request_headers)
 
     if response.status_code == 404:
-        logger.error('no such %s, "%s"' % (namespace, name))
+        logger.error('no such %s, "%s"' % (namespace[:-1], name))
         return None
     
     # raise exceptions for other errors - the auth decorators handle these and
@@ -338,7 +339,8 @@ def addOwner(namespace, name, owner):
     response = requests.put(url, headers=request_headers)
 
     if response.status_code == 404:
-        logger.error('no such %s, "%s"' % (namespace, name))
+        logger.error('no such %s, "%s"' % (namespace[:-1], name))
+        return
 
     # raise exceptions for other errors - the auth decorators handle these and
     # re-try if appropriate
@@ -367,7 +369,8 @@ def removeOwner(namespace, name, owner):
     response = requests.delete(url, headers=request_headers)
 
     if response.status_code == 404:
-        logger.error('no such %s, "%s"' % (namespace, name))
+        logger.error('no such %s, "%s"' % (namespace[:-1], name))
+        return
 
     # raise exceptions for other errors - the auth decorators handle these and
     # re-try if appropriate
